"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SyncdMutation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SyncdOperation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SyncdOperationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SyncdMutation._SyncdOperation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SET: SyncdMutation._SyncdOperation.ValueType  # 0
        REMOVE: SyncdMutation._SyncdOperation.ValueType  # 1

    class SyncdOperation(_SyncdOperation, metaclass=_SyncdOperationEnumTypeWrapper): ...
    SET: SyncdMutation.SyncdOperation.ValueType  # 0
    REMOVE: SyncdMutation.SyncdOperation.ValueType  # 1

    OPERATION_FIELD_NUMBER: builtins.int
    RECORD_FIELD_NUMBER: builtins.int
    operation: global___SyncdMutation.SyncdOperation.ValueType
    @property
    def record(self) -> global___SyncdRecord: ...
    def __init__(
        self,
        *,
        operation: global___SyncdMutation.SyncdOperation.ValueType | None = ...,
        record: global___SyncdRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["operation", b"operation", "record", b"record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["operation", b"operation", "record", b"record"]) -> None: ...

global___SyncdMutation = SyncdMutation

@typing.final
class SyncdVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.int
    def __init__(
        self,
        *,
        version: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["version", b"version"]) -> None: ...

global___SyncdVersion = SyncdVersion

@typing.final
class ExitCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    code: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        code: builtins.int | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["code", b"code", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "text", b"text"]) -> None: ...

global___ExitCode = ExitCode

@typing.final
class SyncdIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_FIELD_NUMBER: builtins.int
    blob: builtins.bytes
    def __init__(
        self,
        *,
        blob: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["blob", b"blob"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["blob", b"blob"]) -> None: ...

global___SyncdIndex = SyncdIndex

@typing.final
class SyncdValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOB_FIELD_NUMBER: builtins.int
    blob: builtins.bytes
    def __init__(
        self,
        *,
        blob: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["blob", b"blob"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["blob", b"blob"]) -> None: ...

global___SyncdValue = SyncdValue

@typing.final
class KeyId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID: builtins.bytes
    def __init__(
        self,
        *,
        ID: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID"]) -> None: ...

global___KeyId = KeyId

@typing.final
class SyncdRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEYID_FIELD_NUMBER: builtins.int
    @property
    def index(self) -> global___SyncdIndex: ...
    @property
    def value(self) -> global___SyncdValue: ...
    @property
    def keyID(self) -> global___KeyId: ...
    def __init__(
        self,
        *,
        index: global___SyncdIndex | None = ...,
        value: global___SyncdValue | None = ...,
        keyID: global___KeyId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["index", b"index", "keyID", b"keyID", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "keyID", b"keyID", "value", b"value"]) -> None: ...

global___SyncdRecord = SyncdRecord

@typing.final
class ExternalBlobReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIAKEY_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    HANDLE_FIELD_NUMBER: builtins.int
    FILESIZEBYTES_FIELD_NUMBER: builtins.int
    FILESHA256_FIELD_NUMBER: builtins.int
    FILEENCSHA256_FIELD_NUMBER: builtins.int
    mediaKey: builtins.bytes
    directPath: builtins.str
    handle: builtins.str
    fileSizeBytes: builtins.int
    fileSHA256: builtins.bytes
    fileEncSHA256: builtins.bytes
    def __init__(
        self,
        *,
        mediaKey: builtins.bytes | None = ...,
        directPath: builtins.str | None = ...,
        handle: builtins.str | None = ...,
        fileSizeBytes: builtins.int | None = ...,
        fileSHA256: builtins.bytes | None = ...,
        fileEncSHA256: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "fileSizeBytes", b"fileSizeBytes", "handle", b"handle", "mediaKey", b"mediaKey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileSHA256", b"fileSHA256", "fileSizeBytes", b"fileSizeBytes", "handle", b"handle", "mediaKey", b"mediaKey"]) -> None: ...

global___ExternalBlobReference = ExternalBlobReference

@typing.final
class SyncdSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    RECORDS_FIELD_NUMBER: builtins.int
    MAC_FIELD_NUMBER: builtins.int
    KEYID_FIELD_NUMBER: builtins.int
    mac: builtins.bytes
    @property
    def version(self) -> global___SyncdVersion: ...
    @property
    def records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncdRecord]: ...
    @property
    def keyID(self) -> global___KeyId: ...
    def __init__(
        self,
        *,
        version: global___SyncdVersion | None = ...,
        records: collections.abc.Iterable[global___SyncdRecord] | None = ...,
        mac: builtins.bytes | None = ...,
        keyID: global___KeyId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["keyID", b"keyID", "mac", b"mac", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["keyID", b"keyID", "mac", b"mac", "records", b"records", "version", b"version"]) -> None: ...

global___SyncdSnapshot = SyncdSnapshot

@typing.final
class SyncdMutations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTATIONS_FIELD_NUMBER: builtins.int
    @property
    def mutations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncdMutation]: ...
    def __init__(
        self,
        *,
        mutations: collections.abc.Iterable[global___SyncdMutation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mutations", b"mutations"]) -> None: ...

global___SyncdMutations = SyncdMutations

@typing.final
class SyncdPatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    MUTATIONS_FIELD_NUMBER: builtins.int
    EXTERNALMUTATIONS_FIELD_NUMBER: builtins.int
    SNAPSHOTMAC_FIELD_NUMBER: builtins.int
    PATCHMAC_FIELD_NUMBER: builtins.int
    KEYID_FIELD_NUMBER: builtins.int
    EXITCODE_FIELD_NUMBER: builtins.int
    DEVICEINDEX_FIELD_NUMBER: builtins.int
    CLIENTDEBUGDATA_FIELD_NUMBER: builtins.int
    snapshotMAC: builtins.bytes
    patchMAC: builtins.bytes
    deviceIndex: builtins.int
    clientDebugData: builtins.bytes
    @property
    def version(self) -> global___SyncdVersion: ...
    @property
    def mutations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SyncdMutation]: ...
    @property
    def externalMutations(self) -> global___ExternalBlobReference: ...
    @property
    def keyID(self) -> global___KeyId: ...
    @property
    def exitCode(self) -> global___ExitCode: ...
    def __init__(
        self,
        *,
        version: global___SyncdVersion | None = ...,
        mutations: collections.abc.Iterable[global___SyncdMutation] | None = ...,
        externalMutations: global___ExternalBlobReference | None = ...,
        snapshotMAC: builtins.bytes | None = ...,
        patchMAC: builtins.bytes | None = ...,
        keyID: global___KeyId | None = ...,
        exitCode: global___ExitCode | None = ...,
        deviceIndex: builtins.int | None = ...,
        clientDebugData: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clientDebugData", b"clientDebugData", "deviceIndex", b"deviceIndex", "exitCode", b"exitCode", "externalMutations", b"externalMutations", "keyID", b"keyID", "patchMAC", b"patchMAC", "snapshotMAC", b"snapshotMAC", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clientDebugData", b"clientDebugData", "deviceIndex", b"deviceIndex", "exitCode", b"exitCode", "externalMutations", b"externalMutations", "keyID", b"keyID", "mutations", b"mutations", "patchMAC", b"patchMAC", "snapshotMAC", b"snapshotMAC", "version", b"version"]) -> None: ...

global___SyncdPatch = SyncdPatch



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waVnameCert/WAWebProtobufsVnameCert.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waVnameCert/WAWebProtobufsVnameCert.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)waVnameCert/WAWebProtobufsVnameCert.proto\x12\x17WAWebProtobufsVnameCert\"\xd0\x02\n\x12\x42izAccountLinkInfo\x12\x1b\n\x13whatsappBizAcctFbid\x18\x01 \x01(\x04\x12\x1a\n\x12whatsappAcctNumber\x18\x02 \x01(\t\x12\x11\n\tissueTime\x18\x03 \x01(\x04\x12P\n\x0bhostStorage\x18\x04 \x01(\x0e\x32;.WAWebProtobufsVnameCert.BizAccountLinkInfo.HostStorageType\x12L\n\x0b\x61\x63\x63ountType\x18\x05 \x01(\x0e\x32\x37.WAWebProtobufsVnameCert.BizAccountLinkInfo.AccountType\"\x1d\n\x0b\x41\x63\x63ountType\x12\x0e\n\nENTERPRISE\x10\x00\"/\n\x0fHostStorageType\x12\x0e\n\nON_PREMISE\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\"\xa2\x04\n\x0f\x42izIdentityInfo\x12K\n\x06vlevel\x18\x01 \x01(\x0e\x32;.WAWebProtobufsVnameCert.BizIdentityInfo.VerifiedLevelValue\x12\x43\n\tvnameCert\x18\x02 \x01(\x0b\x32\x30.WAWebProtobufsVnameCert.VerifiedNameCertificate\x12\x0e\n\x06signed\x18\x03 \x01(\x08\x12\x0f\n\x07revoked\x18\x04 \x01(\x08\x12M\n\x0bhostStorage\x18\x05 \x01(\x0e\x32\x38.WAWebProtobufsVnameCert.BizIdentityInfo.HostStorageType\x12O\n\x0c\x61\x63tualActors\x18\x06 \x01(\x0e\x32\x39.WAWebProtobufsVnameCert.BizIdentityInfo.ActualActorsType\x12\x15\n\rprivacyModeTS\x18\x07 \x01(\x04\x12\x17\n\x0f\x66\x65\x61tureControls\x18\x08 \x01(\x04\"%\n\x10\x41\x63tualActorsType\x12\x08\n\x04SELF\x10\x00\x12\x07\n\x03\x42SP\x10\x01\"/\n\x0fHostStorageType\x12\x0e\n\nON_PREMISE\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\"4\n\x12VerifiedLevelValue\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\x08\n\x04HIGH\x10\x02\"=\n\rLocalizedName\x12\n\n\x02lg\x18\x01 \x01(\t\x12\n\n\x02lc\x18\x02 \x01(\t\x12\x14\n\x0cverifiedName\x18\x03 \x01(\t\"\xeb\x01\n\x17VerifiedNameCertificate\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x17\n\x0fserverSignature\x18\x03 \x01(\x0c\x1a\x92\x01\n\x07\x44\x65tails\x12\x0e\n\x06serial\x18\x01 \x01(\x04\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x14\n\x0cverifiedName\x18\x04 \x01(\t\x12>\n\x0elocalizedNames\x18\x08 \x03(\x0b\x32&.WAWebProtobufsVnameCert.LocalizedName\x12\x11\n\tissueTime\x18\n \x01(\x04\"q\n\x11\x42izAccountPayload\x12\x43\n\tvnameCert\x18\x01 \x01(\x0b\x32\x30.WAWebProtobufsVnameCert.VerifiedNameCertificate\x12\x17\n\x0f\x62izAcctLinkInfo\x18\x02 \x01(\x0c\x42\'Z%go.mau.fi/whatsmeow/proto/waVnameCert')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waVnameCert.WAWebProtobufsVnameCert_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%go.mau.fi/whatsmeow/proto/waVnameCert'
  _globals['_BIZACCOUNTLINKINFO']._serialized_start=71
  _globals['_BIZACCOUNTLINKINFO']._serialized_end=407
  _globals['_BIZACCOUNTLINKINFO_ACCOUNTTYPE']._serialized_start=329
  _globals['_BIZACCOUNTLINKINFO_ACCOUNTTYPE']._serialized_end=358
  _globals['_BIZACCOUNTLINKINFO_HOSTSTORAGETYPE']._serialized_start=360
  _globals['_BIZACCOUNTLINKINFO_HOSTSTORAGETYPE']._serialized_end=407
  _globals['_BIZIDENTITYINFO']._serialized_start=410
  _globals['_BIZIDENTITYINFO']._serialized_end=956
  _globals['_BIZIDENTITYINFO_ACTUALACTORSTYPE']._serialized_start=816
  _globals['_BIZIDENTITYINFO_ACTUALACTORSTYPE']._serialized_end=853
  _globals['_BIZIDENTITYINFO_HOSTSTORAGETYPE']._serialized_start=360
  _globals['_BIZIDENTITYINFO_HOSTSTORAGETYPE']._serialized_end=407
  _globals['_BIZIDENTITYINFO_VERIFIEDLEVELVALUE']._serialized_start=904
  _globals['_BIZIDENTITYINFO_VERIFIEDLEVELVALUE']._serialized_end=956
  _globals['_LOCALIZEDNAME']._serialized_start=958
  _globals['_LOCALIZEDNAME']._serialized_end=1019
  _globals['_VERIFIEDNAMECERTIFICATE']._serialized_start=1022
  _globals['_VERIFIEDNAMECERTIFICATE']._serialized_end=1257
  _globals['_VERIFIEDNAMECERTIFICATE_DETAILS']._serialized_start=1111
  _globals['_VERIFIEDNAMECERTIFICATE_DETAILS']._serialized_end=1257
  _globals['_BIZACCOUNTPAYLOAD']._serialized_start=1259
  _globals['_BIZACCOUNTPAYLOAD']._serialized_end=1372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waWa6/WAWebProtobufsWa6.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waWa6/WAWebProtobufsWa6.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dwaWa6/WAWebProtobufsWa6.proto\x12\x11WAWebProtobufsWa6\"\xae!\n\rClientPayload\x12\x10\n\x08username\x18\x01 \x01(\x04\x12\x0f\n\x07passive\x18\x03 \x01(\x08\x12=\n\tuserAgent\x18\x05 \x01(\x0b\x32*.WAWebProtobufsWa6.ClientPayload.UserAgent\x12\x39\n\x07webInfo\x18\x06 \x01(\x0b\x32(.WAWebProtobufsWa6.ClientPayload.WebInfo\x12\x10\n\x08pushName\x18\x07 \x01(\t\x12\x11\n\tsessionID\x18\t \x01(\x0f\x12\x14\n\x0cshortConnect\x18\n \x01(\x08\x12\x41\n\x0b\x63onnectType\x18\x0c \x01(\x0e\x32,.WAWebProtobufsWa6.ClientPayload.ConnectType\x12\x45\n\rconnectReason\x18\r \x01(\x0e\x32..WAWebProtobufsWa6.ClientPayload.ConnectReason\x12\x0e\n\x06shards\x18\x0e \x03(\x05\x12=\n\tdnsSource\x18\x0f \x01(\x0b\x32*.WAWebProtobufsWa6.ClientPayload.DNSSource\x12\x1b\n\x13\x63onnectAttemptCount\x18\x10 \x01(\r\x12\x0e\n\x06\x64\x65vice\x18\x12 \x01(\r\x12Y\n\x11\x64\x65vicePairingData\x18\x13 \x01(\x0b\x32>.WAWebProtobufsWa6.ClientPayload.DevicePairingRegistrationData\x12\x39\n\x07product\x18\x14 \x01(\x0e\x32(.WAWebProtobufsWa6.ClientPayload.Product\x12\r\n\x05\x66\x62\x43\x61t\x18\x15 \x01(\x0c\x12\x13\n\x0b\x66\x62UserAgent\x18\x16 \x01(\x0c\x12\n\n\x02oc\x18\x17 \x01(\x08\x12\n\n\x02lc\x18\x18 \x01(\x05\x12I\n\x0fiosAppExtension\x18\x1e \x01(\x0e\x32\x30.WAWebProtobufsWa6.ClientPayload.IOSAppExtension\x12\x0f\n\x07\x66\x62\x41ppID\x18\x1f \x01(\x04\x12\x12\n\nfbDeviceID\x18  \x01(\x0c\x12\x0c\n\x04pull\x18! \x01(\x08\x12\x14\n\x0cpaddingBytes\x18\" \x01(\x0c\x12\x11\n\tyearClass\x18$ \x01(\x05\x12\x10\n\x08memClass\x18% \x01(\x05\x12\x41\n\x0binteropData\x18& \x01(\x0b\x32,.WAWebProtobufsWa6.ClientPayload.InteropData\x12S\n\x14trafficAnonymization\x18( \x01(\x0e\x32\x35.WAWebProtobufsWa6.ClientPayload.TrafficAnonymization\x12\x15\n\rlidDbMigrated\x18) \x01(\x08\x12\x41\n\x0b\x61\x63\x63ountType\x18* \x01(\x0e\x32,.WAWebProtobufsWa6.ClientPayload.AccountType\x1a\xd4\x01\n\tDNSSource\x12Q\n\tdnsMethod\x18\x0f \x01(\x0e\x32>.WAWebProtobufsWa6.ClientPayload.DNSSource.DNSResolutionMethod\x12\x11\n\tappCached\x18\x10 \x01(\x08\"a\n\x13\x44NSResolutionMethod\x12\n\n\x06SYSTEM\x10\x00\x12\n\n\x06GOOGLE\x10\x01\x12\r\n\tHARDCODED\x10\x02\x12\x0c\n\x08OVERRIDE\x10\x03\x12\x0c\n\x08\x46\x41LLBACK\x10\x04\x12\x07\n\x03MNS\x10\x05\x1a\xee\x04\n\x07WebInfo\x12\x10\n\x08refToken\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12I\n\x0bwebdPayload\x18\x03 \x01(\x0b\x32\x34.WAWebProtobufsWa6.ClientPayload.WebInfo.WebdPayload\x12O\n\x0ewebSubPlatform\x18\x04 \x01(\x0e\x32\x37.WAWebProtobufsWa6.ClientPayload.WebInfo.WebSubPlatform\x1a\xbb\x02\n\x0bWebdPayload\x12\x1c\n\x14usesParticipantInKey\x18\x01 \x01(\x08\x12\x1f\n\x17supportsStarredMessages\x18\x02 \x01(\x08\x12 \n\x18supportsDocumentMessages\x18\x03 \x01(\x08\x12\x1b\n\x13supportsURLMessages\x18\x04 \x01(\x08\x12\x1a\n\x12supportsMediaRetry\x18\x05 \x01(\x08\x12\x18\n\x10supportsE2EImage\x18\x06 \x01(\x08\x12\x18\n\x10supportsE2EVideo\x18\x07 \x01(\x08\x12\x18\n\x10supportsE2EAudio\x18\x08 \x01(\x08\x12\x1b\n\x13supportsE2EDocument\x18\t \x01(\x08\x12\x15\n\rdocumentTypes\x18\n \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x0b \x01(\x0c\"f\n\x0eWebSubPlatform\x12\x0f\n\x0bWEB_BROWSER\x10\x00\x12\r\n\tAPP_STORE\x10\x01\x12\r\n\tWIN_STORE\x10\x02\x12\n\n\x06\x44\x41RWIN\x10\x03\x12\t\n\x05WIN32\x10\x04\x12\x0e\n\nWIN_HYBRID\x10\x05\x1a\xba\n\n\tUserAgent\x12\x45\n\x08platform\x18\x01 \x01(\x0e\x32\x33.WAWebProtobufsWa6.ClientPayload.UserAgent.Platform\x12I\n\nappVersion\x18\x02 \x01(\x0b\x32\x35.WAWebProtobufsWa6.ClientPayload.UserAgent.AppVersion\x12\x0b\n\x03mcc\x18\x03 \x01(\t\x12\x0b\n\x03mnc\x18\x04 \x01(\t\x12\x11\n\tosVersion\x18\x05 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x06 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x07 \x01(\t\x12\x15\n\rosBuildNumber\x18\x08 \x01(\t\x12\x0f\n\x07phoneID\x18\t \x01(\t\x12Q\n\x0ereleaseChannel\x18\n \x01(\x0e\x32\x39.WAWebProtobufsWa6.ClientPayload.UserAgent.ReleaseChannel\x12\x1d\n\x15localeLanguageIso6391\x18\x0b \x01(\t\x12#\n\x1blocaleCountryIso31661Alpha2\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x65viceBoard\x18\r \x01(\t\x12\x13\n\x0b\x64\x65viceExpID\x18\x0e \x01(\t\x12I\n\ndeviceType\x18\x0f \x01(\x0e\x32\x35.WAWebProtobufsWa6.ClientPayload.UserAgent.DeviceType\x12\x17\n\x0f\x64\x65viceModelType\x18\x10 \x01(\t\x1ag\n\nAppVersion\x12\x0f\n\x07primary\x18\x01 \x01(\r\x12\x11\n\tsecondary\x18\x02 \x01(\r\x12\x10\n\x08tertiary\x18\x03 \x01(\r\x12\x12\n\nquaternary\x18\x04 \x01(\r\x12\x0f\n\x07quinary\x18\x05 \x01(\r\"F\n\nDeviceType\x12\t\n\x05PHONE\x10\x00\x12\n\n\x06TABLET\x10\x01\x12\x0b\n\x07\x44\x45SKTOP\x10\x02\x12\x0c\n\x08WEARABLE\x10\x03\x12\x06\n\x02VR\x10\x04\"=\n\x0eReleaseChannel\x12\x0b\n\x07RELEASE\x10\x00\x12\x08\n\x04\x42\x45TA\x10\x01\x12\t\n\x05\x41LPHA\x10\x02\x12\t\n\x05\x44\x45\x42UG\x10\x03\"\x8a\x04\n\x08Platform\x12\x0b\n\x07\x41NDROID\x10\x00\x12\x07\n\x03IOS\x10\x01\x12\x11\n\rWINDOWS_PHONE\x10\x02\x12\x0e\n\nBLACKBERRY\x10\x03\x12\x0f\n\x0b\x42LACKBERRYX\x10\x04\x12\x07\n\x03S40\x10\x05\x12\x07\n\x03S60\x10\x06\x12\x11\n\rPYTHON_CLIENT\x10\x07\x12\t\n\x05TIZEN\x10\x08\x12\x0e\n\nENTERPRISE\x10\t\x12\x0f\n\x0bSMB_ANDROID\x10\n\x12\t\n\x05KAIOS\x10\x0b\x12\x0b\n\x07SMB_IOS\x10\x0c\x12\x0b\n\x07WINDOWS\x10\r\x12\x07\n\x03WEB\x10\x0e\x12\n\n\x06PORTAL\x10\x0f\x12\x11\n\rGREEN_ANDROID\x10\x10\x12\x10\n\x0cGREEN_IPHONE\x10\x11\x12\x10\n\x0c\x42LUE_ANDROID\x10\x12\x12\x0f\n\x0b\x42LUE_IPHONE\x10\x13\x12\x12\n\x0e\x46\x42LITE_ANDROID\x10\x14\x12\x11\n\rMLITE_ANDROID\x10\x15\x12\x12\n\x0eIGLITE_ANDROID\x10\x16\x12\x08\n\x04PAGE\x10\x17\x12\t\n\x05MACOS\x10\x18\x12\x0e\n\nOCULUS_MSG\x10\x19\x12\x0f\n\x0bOCULUS_CALL\x10\x1a\x12\t\n\x05MILAN\x10\x1b\x12\x08\n\x04\x43\x41PI\x10\x1c\x12\n\n\x06WEAROS\x10\x1d\x12\x0c\n\x08\x41RDEVICE\x10\x1e\x12\x0c\n\x08VRDEVICE\x10\x1f\x12\x0c\n\x08\x42LUE_WEB\x10 \x12\x08\n\x04IPAD\x10!\x12\x08\n\x04TEST\x10\"\x12\x11\n\rSMART_GLASSES\x10#\x1aK\n\x0bInteropData\x12\x11\n\taccountID\x18\x01 \x01(\x04\x12\r\n\x05token\x18\x02 \x01(\x0c\x12\x1a\n\x12\x65nableReadReceipts\x18\x03 \x01(\x08\x1a\xae\x01\n\x1d\x44\x65vicePairingRegistrationData\x12\x0e\n\x06\x65Regid\x18\x01 \x01(\x0c\x12\x10\n\x08\x65Keytype\x18\x02 \x01(\x0c\x12\x0e\n\x06\x65Ident\x18\x03 \x01(\x0c\x12\x0f\n\x07\x65SkeyID\x18\x04 \x01(\x0c\x12\x10\n\x08\x65SkeyVal\x18\x05 \x01(\x0c\x12\x10\n\x08\x65SkeySig\x18\x06 \x01(\x0c\x12\x11\n\tbuildHash\x18\x07 \x01(\x0c\x12\x13\n\x0b\x64\x65viceProps\x18\x08 \x01(\x0c\"-\n\x14TrafficAnonymization\x12\x07\n\x03OFF\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\"%\n\x0b\x41\x63\x63ountType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\t\n\x05GUEST\x10\x01\"W\n\x07Product\x12\x0c\n\x08WHATSAPP\x10\x00\x12\r\n\tMESSENGER\x10\x01\x12\x0b\n\x07INTEROP\x10\x02\x12\x10\n\x0cINTEROP_MSGR\x10\x03\x12\x10\n\x0cWHATSAPP_LID\x10\x04\"\xb0\x02\n\x0b\x43onnectType\x12\x14\n\x10\x43\x45LLULAR_UNKNOWN\x10\x00\x12\x10\n\x0cWIFI_UNKNOWN\x10\x01\x12\x11\n\rCELLULAR_EDGE\x10\x64\x12\x11\n\rCELLULAR_IDEN\x10\x65\x12\x11\n\rCELLULAR_UMTS\x10\x66\x12\x11\n\rCELLULAR_EVDO\x10g\x12\x11\n\rCELLULAR_GPRS\x10h\x12\x12\n\x0e\x43\x45LLULAR_HSDPA\x10i\x12\x12\n\x0e\x43\x45LLULAR_HSUPA\x10j\x12\x11\n\rCELLULAR_HSPA\x10k\x12\x11\n\rCELLULAR_CDMA\x10l\x12\x12\n\x0e\x43\x45LLULAR_1XRTT\x10m\x12\x12\n\x0e\x43\x45LLULAR_EHRPD\x10n\x12\x10\n\x0c\x43\x45LLULAR_LTE\x10o\x12\x12\n\x0e\x43\x45LLULAR_HSPAP\x10p\"\x86\x01\n\rConnectReason\x12\x08\n\x04PUSH\x10\x00\x12\x12\n\x0eUSER_ACTIVATED\x10\x01\x12\r\n\tSCHEDULED\x10\x02\x12\x13\n\x0f\x45RROR_RECONNECT\x10\x03\x12\x12\n\x0eNETWORK_SWITCH\x10\x04\x12\x12\n\x0ePING_RECONNECT\x10\x05\x12\x0b\n\x07UNKNOWN\x10\x06\"T\n\x0fIOSAppExtension\x12\x13\n\x0fSHARE_EXTENSION\x10\x00\x12\x15\n\x11SERVICE_EXTENSION\x10\x01\x12\x15\n\x11INTENTS_EXTENSION\x10\x02\"\x9d\x03\n\x10HandshakeMessage\x12\x44\n\x0b\x63lientHello\x18\x02 \x01(\x0b\x32/.WAWebProtobufsWa6.HandshakeMessage.ClientHello\x12\x44\n\x0bserverHello\x18\x03 \x01(\x0b\x32/.WAWebProtobufsWa6.HandshakeMessage.ServerHello\x12\x46\n\x0c\x63lientFinish\x18\x04 \x01(\x0b\x32\x30.WAWebProtobufsWa6.HandshakeMessage.ClientFinish\x1a/\n\x0c\x43lientFinish\x12\x0e\n\x06static\x18\x01 \x01(\x0c\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x1a\x41\n\x0bServerHello\x12\x11\n\tephemeral\x18\x01 \x01(\x0c\x12\x0e\n\x06static\x18\x02 \x01(\x0c\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x1a\x41\n\x0b\x43lientHello\x12\x11\n\tephemeral\x18\x01 \x01(\x0c\x12\x0e\n\x06static\x18\x02 \x01(\x0c\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x42!Z\x1fgo.mau.fi/whatsmeow/proto/waWa6')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waWa6.WAWebProtobufsWa6_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\037go.mau.fi/whatsmeow/proto/waWa6'
  _globals['_CLIENTPAYLOAD']._serialized_start=53
  _globals['_CLIENTPAYLOAD']._serialized_end=4323
  _globals['_CLIENTPAYLOAD_DNSSOURCE']._serialized_start=1186
  _globals['_CLIENTPAYLOAD_DNSSOURCE']._serialized_end=1398
  _globals['_CLIENTPAYLOAD_DNSSOURCE_DNSRESOLUTIONMETHOD']._serialized_start=1301
  _globals['_CLIENTPAYLOAD_DNSSOURCE_DNSRESOLUTIONMETHOD']._serialized_end=1398
  _globals['_CLIENTPAYLOAD_WEBINFO']._serialized_start=1401
  _globals['_CLIENTPAYLOAD_WEBINFO']._serialized_end=2023
  _globals['_CLIENTPAYLOAD_WEBINFO_WEBDPAYLOAD']._serialized_start=1604
  _globals['_CLIENTPAYLOAD_WEBINFO_WEBDPAYLOAD']._serialized_end=1919
  _globals['_CLIENTPAYLOAD_WEBINFO_WEBSUBPLATFORM']._serialized_start=1921
  _globals['_CLIENTPAYLOAD_WEBINFO_WEBSUBPLATFORM']._serialized_end=2023
  _globals['_CLIENTPAYLOAD_USERAGENT']._serialized_start=2026
  _globals['_CLIENTPAYLOAD_USERAGENT']._serialized_end=3364
  _globals['_CLIENTPAYLOAD_USERAGENT_APPVERSION']._serialized_start=2601
  _globals['_CLIENTPAYLOAD_USERAGENT_APPVERSION']._serialized_end=2704
  _globals['_CLIENTPAYLOAD_USERAGENT_DEVICETYPE']._serialized_start=2706
  _globals['_CLIENTPAYLOAD_USERAGENT_DEVICETYPE']._serialized_end=2776
  _globals['_CLIENTPAYLOAD_USERAGENT_RELEASECHANNEL']._serialized_start=2778
  _globals['_CLIENTPAYLOAD_USERAGENT_RELEASECHANNEL']._serialized_end=2839
  _globals['_CLIENTPAYLOAD_USERAGENT_PLATFORM']._serialized_start=2842
  _globals['_CLIENTPAYLOAD_USERAGENT_PLATFORM']._serialized_end=3364
  _globals['_CLIENTPAYLOAD_INTEROPDATA']._serialized_start=3366
  _globals['_CLIENTPAYLOAD_INTEROPDATA']._serialized_end=3441
  _globals['_CLIENTPAYLOAD_DEVICEPAIRINGREGISTRATIONDATA']._serialized_start=3444
  _globals['_CLIENTPAYLOAD_DEVICEPAIRINGREGISTRATIONDATA']._serialized_end=3618
  _globals['_CLIENTPAYLOAD_TRAFFICANONYMIZATION']._serialized_start=3620
  _globals['_CLIENTPAYLOAD_TRAFFICANONYMIZATION']._serialized_end=3665
  _globals['_CLIENTPAYLOAD_ACCOUNTTYPE']._serialized_start=3667
  _globals['_CLIENTPAYLOAD_ACCOUNTTYPE']._serialized_end=3704
  _globals['_CLIENTPAYLOAD_PRODUCT']._serialized_start=3706
  _globals['_CLIENTPAYLOAD_PRODUCT']._serialized_end=3793
  _globals['_CLIENTPAYLOAD_CONNECTTYPE']._serialized_start=3796
  _globals['_CLIENTPAYLOAD_CONNECTTYPE']._serialized_end=4100
  _globals['_CLIENTPAYLOAD_CONNECTREASON']._serialized_start=4103
  _globals['_CLIENTPAYLOAD_CONNECTREASON']._serialized_end=4237
  _globals['_CLIENTPAYLOAD_IOSAPPEXTENSION']._serialized_start=4239
  _globals['_CLIENTPAYLOAD_IOSAPPEXTENSION']._serialized_end=4323
  _globals['_HANDSHAKEMESSAGE']._serialized_start=4326
  _globals['_HANDSHAKEMESSAGE']._serialized_end=4739
  _globals['_HANDSHAKEMESSAGE_CLIENTFINISH']._serialized_start=4558
  _globals['_HANDSHAKEMESSAGE_CLIENTFINISH']._serialized_end=4605
  _globals['_HANDSHAKEMESSAGE_SERVERHELLO']._serialized_start=4607
  _globals['_HANDSHAKEMESSAGE_SERVERHELLO']._serialized_end=4672
  _globals['_HANDSHAKEMESSAGE_CLIENTHELLO']._serialized_start=4674
  _globals['_HANDSHAKEMESSAGE_CLIENTHELLO']._serialized_end=4739
# @@protoc_insertion_point(module_scope)
